Package: tmvmixnorm
Type: Package
Title: Sampling from Truncated Multivariate Normal and t Distributions
Version: 1.2.0
Authors@R: c(person("Ting Fung", "Ma", email = "tingfung@mailbox.sc.edu", role = c("cre", "aut")),
    person("Sujit K.", "Ghosh", email = "sujit_ghosh@ncsu.edu", role = "aut"),
    person("Yifang", "Li", role = "aut"))
Maintainer: Ting Fung Ma <tingfung@mailbox.sc.edu>
Description: Efficient sampling of truncated multivariate (scale) mixtures of normals under linear inequality constraints is nontrivial due to the analytically intractable normalizing constant. Meanwhile, traditional methods may subject to numerical issues, especially when the dimension is high and dependence is strong.    Algorithms proposed by Li and Ghosh (2015) <doi: 10.1080/15598608.2014.996690> are adopted for overcoming difficulties in simulating truncated distributions. Efficient rejection sampling for simulating truncated univariate normal distribution is included in the package, which shows superiority in terms of acceptance rate and numerical stability compared to existing methods and R packages. An efficient function for sampling from truncated multivariate normal distribution subject to convex polytope restriction regions based on Gibbs sampler for conditional truncated univariate distribution is provided. By extending the sampling method, a function for sampling truncated multivariate Student's t distribution is also developed.     Moreover, the proposed method and computation remain valid for high dimensional and strong dependence scenarios. Empirical results in Li and Ghosh (2015) <doi: 10.1080/15598608.2014.996690> illustrated the superior performance in terms of various criteria (e.g. mixing and integrated auto-correlation time).
License: GPL-2
Encoding: UTF-8
Depends: R (>= 3.2.0)
Imports: stats, MASS
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-08 13:19:57 UTC; ralph
Author: Ting Fung Ma [cre, aut],
  Sujit K. Ghosh [aut],
  Yifang Li [aut]
Repository: CRAN
Date/Publication: 2026-05-11 07:50:02 UTC
Built: R 4.5.2; ; 2026-05-11 10:39:11 UTC; unix
